@@ -82,10 +82,18 @@ local({
 #
 #  tests/imageops.R
 #
-#   $Revision: 1.40 $   $Date: 2022/10/23 01:57:03 $
+#   $Revision: 1.43 $   $Date: 2023/08/29 01:03:59 $
 #
 
 
+if(ALWAYS) {
+  local({
+    #' Test of case 'CONNECT=24' in src/distmapbin.[ch]
+    #' Distance transform with 24-connected neighbours
+    A <- distmap(heather$coarse, connect=24)
+  })
+}
+
 if(FULLTEST) {
 local({
   #' cases of 'im' data
@@ -135,7 +143,10 @@ local({
   
   ##
   d <- distmap(cells, dimyx=32)
-  Z <- connected(d <= 0.06, method="interpreted")
+  D6 <- (d <= 0.06)
+  Z <- connected(D6, method="interpreted")
+  Z <- connected(D6,                       connect=4)
+  Z <- connected(D6, method="interpreted", connect=4)
 
   a <- where.max(d, first=FALSE)
   a <- where.min(d, first=FALSE)
